plist
=====

Use the **plist** resource to manage property list files (plists) and their content.
The [**plist**](https://github.com/Microsoft/macos-cookbook/blob/master/resources/plist.rb) resource manages the state
the delared plist `path`. Since each plist resource instance represents only one
setting, you may end up with several plist resource calls in a given recipe. Although
this may seem like overkill, it allows us to have a fully idempotent resource with
fine granularity.

During the `chef-client` run, the client knows to check the state of the plist
before changing any values. It also makes sure that the plist is in binary format
so that the settings can be interpreted correctly by the operating system.

Prior knowledge of using commandline utilities such as
`defaults`,
`plutil`,
and `PlistBuddy`
will be useful when implementing the **plist** resource.

Syntax
------

The full syntax for all of the properties that are available to the **plist**
resource is:

```ruby
plist 'description' do
  path                         String # defaults to 'description' if not specified
  entry                        String
  value                        TrueClass, FalseClass, String, Integer, Float
  action                       Symbol # defaults to :set if not specified
  encoding                     String # defaults to 'binary' if not specified.
  owner                        String # defaults to 'root' if not specified.
  group                        String # defaults to 'wheel' if not specified.
  mode                         String, Integer 
end
```

Actions
-------

This resource has the following actions:

`:set`

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Set `entry` to `value` in `path`

Examples
--------

**Show invisible files**

```ruby
plist 'show hidden files' do
  path '/Users/vagrant/Library/Preferences/com.apple.finder.plist'
  entry 'AppleShowAllFiles'
  value true
end
```

where

`path` is the absolute path to the `com.apple.finder.plist` plist file

`entry` is the representing the plist entry `'AppleShowAllFiles'`

`value` is the entry's value to boolean type: `true`
